import json
import logging

import redis

from inventory_provider.tasks.app import app
from inventory_provider.constants import TASK_LOGGER_NAME


def get_router_details(router):
    task_logger = logging.getLogger(TASK_LOGGER_NAME)
    task_logger.debug("launching task: "
                      "inventory_provider.tasks.worker.juniper_refresh_bgp")
    app.send_task(
        'inventory_provider.tasks.worker.juniper_refresh_bgp',
        args=[router["hostname"]])
    task_logger.debug("launching task: "
                      "inventory_provider.tasks.worker.juniper_refresh_vrr")
    app.send_task(
        'inventory_provider.tasks.worker.juniper_refresh_vrr',
        args=[router["hostname"]])

    task_logger.debug("launching task: "
                      "inventory_provider"
                      ".tasks.worker.juniper_refresh_interfaces")
    app.send_task(
        'inventory_provider.tasks.worker.juniper_refresh_interfaces',
        args=[router["hostname"]])

    task_logger.debug("launching task: "
                      "inventory_provider"
                      ".tasks.worker.snmp_refresh_interfaces")
    app.send_task(
        'inventory_provider.tasks.worker.snmp_refresh_interfaces',
        args=[router["hostname"], router["community"]])

    task_logger.debug("launching task: "
                      "inventory_provider"
                      ".tasks.worker.netconf_refresh_config")
    app.send_task(
        'inventory_provider.tasks.worker.netconf_refresh_config',
        args=[router["hostname"]])




def update_network_details(params):
    task_logger = logging.getLogger(TASK_LOGGER_NAME)
    for r in params["routers"]:
        task_logger.info("fetching router details for: %r" % r)
        get_router_details(r)


def load_network_details(redis_params):

    r = redis.StrictRedis(
        host=redis_params["hostname"],
        port=redis_params["port"])

    result = {}
    for hostname in r.keys():
        host = {}
        for key in r.hkeys(name=hostname):
            host[key.decode("utf-8")] = json.loads(
                r.hget(hostname, key).decode("utf-8")
            )
        result[hostname.decode("utf-8")] = host

    return result


if __name__ == "__main__":
    from inventory_provider import config
    with open("config.json") as f:
        params = config.load(f)

    update_network_details(params)

    # network_info = load_network_details(params["redis"])
    # with open("./router-info.json", "w") as f:
    #     f.write(json.dumps(network_info))
